@@ -313,16 +313,9 @@ read_config(char *file, struct cfentry *cfe, int count, void *data)
                 case CF_INTEGER:
                 case CF_INT_PLUS:
                     {
-                        size_t value;
+                        unsigned int value;
                         char   *tmp;
 
-                        if (*str == '\0') {
-                            SYSLOG(LOG_WARNING, ERR_CONF_SYNTAXERR,
-                                                file, nline);
-                            error++;
-                            break;
-                        }
-
                         value = strtol(str, &tmp, 10);
 
                         /* skip trailing blank, if *tmp is blank space */
