@@ -2,8 +2,8 @@
  * Mail Utility Library
  *
  * $RCSfile: libdgmail.c,v $
- * $Revision: 1.3 $
- * $Date: 2009/04/17 08:40:57 $
+ * $Revision: 1.4 $
+ * $Date: 2011/08/03 06:12:40 $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -710,21 +710,23 @@ b64char2i(int c)
 }
 
 /*
- * get_addrpart
+ * get_addrpart_real
  *
  * ǽ
  *	᡼륢ɥ쥹μ
- *	"name <address>'' ޤ "address (name)'' ޤ"address"η
+ * 	"name <address>'' ޤ "address (name)'' ޤ"address"η
  *
  * 
  *	unsigned char *str	᡼륢ɥ쥹Ϣإå
+ *	int translateflg	TRANSLATE:ʸѴ
+ *				NOTRANSLATE:ʸѴʤ
  *
  * ֤
  *	bstr			᡼륢ɥ쥹ʸ
  *	NULL			ȥ顼
  */
 char *
-get_addrpart(unsigned char *str)
+get_addrpart_real(unsigned char *str, int translateflg)
 {
     int mode = MODE_0;
     int len = strlen(str);
@@ -946,12 +948,52 @@ get_addrpart(unsigned char *str)
     /* copy the string */
     nlen = end - start + 1;
     for (i = 0; i < nlen; i ++) {
-        addr[i] = tolower(str[start + i]);
+        if (translateflg == TRANSLATE) {
+            addr[i] = tolower(str[start + i]);
+        } else {
+            addr[i] = str[start + i];
+        }
     }
     addr[i] = '\0';
     return addr;
 }
 
+/*
+ * get_addrpart
+ *
+ * ǽ
+ *	get_addrpart_realƤӾʸѴ줿᡼륢ɥ쥹
+ *
+ * 
+ *	unsigned char *str	᡼륢ɥ쥹Ϣإå
+ *
+ * ֤
+ *				᡼륢ɥ쥹ʸ
+ */
+char *
+get_addrpart(unsigned char *str)
+{
+    return get_addrpart_real(str, TRANSLATE);
+}
+
+/*
+ * get_addrpart_notranslate
+ *
+ * ǽ
+ *      get_addrpart_realƤӥ᡼륢ɥ쥹
+ *
+ * 
+ *	unsigned char *str	᡼륢ɥ쥹Ϣإå
+ *
+ * ֤
+ *				᡼륢ɥ쥹ʸ
+ */
+char *
+get_addrpart_notranslate(unsigned char *str)
+{
+    return get_addrpart_real(str, NOTRANSLATE);
+}
+
 /*
  * get_from
  *
@@ -1007,8 +1049,8 @@ encode_mime(char *str, int len)
     char   *ip;
     char   *op;
     struct strset ss;
-    size_t     ileft;
-    size_t     oleft;
+    int     ileft;
+    int     oleft;
     int     ret;
     iconv_t icd;
     int     error;
@@ -1016,8 +1058,8 @@ encode_mime(char *str, int len)
     /* ñ̤ʬ䤹뤿֥Хåե */
     char    str_divide[ENC_STR_DIVIDE_LEN + 2];
     char   *str_divide_tmp;
-    size_t     str_divide_len;
-    size_t     str_divide_len_tmp;
+    int     str_divide_len;
+    int     str_divide_len_tmp;
     int     b64_enc_size;
 
     strset_init(&ss);
