@@ -1,7 +1,7 @@
 /*
  *  $Source: /home/cvsroot/SaMMA/src/mailsave.h,v $
- *  $Revision: 1.1.1.1 $
- *  $Date: 2009/07/23 01:42:12 $
+ *  $Revision: 1.2 $
+ *  $Date: 2010/04/10 02:59:57 $
  */
 
 #ifndef __MAILZIP_MAILSAVE_H__
@@ -29,8 +29,10 @@ struct mailinfo {
 #define MS_STATUS_MAILSAVE  4
 #define MS_STATUS_ERROR     8
 #define MS_STATUS_READ	    16
+#define MBSIZE              1048576
 
 int mailsave_write(struct mailinfo *, struct config *, char *, int);
 int mailsave_clean(struct mailinfo *);
+int mailsave_reset(struct mailinfo *);
 
 #endif /* __MAILZIP_MAILSAVE_H__ */
