@@ -20,10 +20,14 @@
 
 /*
  * $RCSfile: mailzip_db.c,v $
- * $Revision: 1.5 $
- * $Date: 2010/02/25 03:35:48 $
+ * $Revision: 1.6 $
+ * $Date: 2010/07/15 06:27:30 $
  */
 
+#ifdef HAVE_STRNDUP
+#define _GNU_SOURCE
+#endif /* HAVE_STRNDUP */
+
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
