@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: samma_policy.c,v $
- * $Revision: 1.40 $
- * $Date: 2010/11/08 06:03:14 $
+ * $Revision: 1.42 $
+ * $Date: 2011/08/29 02:28:24 $
  */
 
 #include <stdio.h>
@@ -227,6 +227,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
             free_search_rcptaddr(&res);
             return ERROR;
         }
+
         /* get userdn */
         ret = ldap_get_userdn(res.ld, cfg->cf_ldapbasedn, sender, rcptaddr, 
 			      cfg->cf_ldapfilter, &res.userdn);
@@ -305,6 +306,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
  *       ENC            	encryption
  *       NOT_ENC        	no encryption
  *       ERROR  	 	database error
+ *	 MALLOC_ERROR		alloc error
  */
 int
 search_rcptaddr_ldap(struct search_res *res, struct config *cfg, 
@@ -316,13 +318,22 @@ search_rcptaddr_ldap(struct search_res *res, struct config *cfg,
     struct tm *ti;
     time_t now;
     char pass[BUFSIZE];
+    char *searchaddr =NULL;
 
     data.addr = NULL;
     data.pass = NULL;
     data.addr_len = 0;
 
-    ret = ldap_search_policy(res->ld, cfg->cf_ldapbasedn, rcptaddr, 
+    /* translate lower string */
+    searchaddr = str_tolower(rcptaddr);
+    if (searchaddr == NULL) {
+        /* malloc error */
+        return MALLOC_ERROR;
+    }
+    
+    ret = ldap_search_policy(res->ld, cfg->cf_ldapbasedn, searchaddr, 
 			      res->userdn, &data);
+    free(searchaddr);
     if ((ret == LDAP_ERROR) || (ret == MALLOC_ERROR)) {
         return ERROR;
     } else if (ret == NOT_ENC) {
@@ -437,23 +448,35 @@ search_rcptaddr_bdb(struct search_res *res, struct config *cfg, char *rcptaddr,
     struct tm *ti;
     time_t now;
     char tmppass[BUFSIZE];
+    char *searchaddr =NULL;
 
-    ret = search_rcptstr_bdb(res->rcpt_dbp, cfg->cf_rcptdbpath, rcptaddr, rcptaddr,
+    /* translate lower string */
+    searchaddr = str_tolower(rcptaddr);
+    if (rcptaddr == NULL) {
+        /* malloc error */
+        return MALLOC_ERROR;
+    }
+
+    ret = search_rcptstr_bdb(res->rcpt_dbp, cfg->cf_rcptdbpath, rcptaddr, searchaddr,
 			     res->onetime_pass, passlist, rdmpasslist);
     if (ret < 0) {
+        free(searchaddr);
         return DB_ERROR;
     } else if ((ret == NOT_ENC) || (ret == ENC)) {
+        free(searchaddr);
 	return RECORD_FOUND;
     }
 
     /* make fqdn */
-    fqdn = strchr(rcptaddr, ATMARK);
+    fqdn = strchr(searchaddr, ATMARK);
     if (fqdn == NULL) {
+        free(searchaddr);
         return RECORD_NOTFOUND;
     }
 
     ret = search_rcptstr_bdb(res->rcpt_dbp, cfg->cf_rcptdbpath, rcptaddr, fqdn,
 			     res->onetime_pass, passlist, rdmpasslist);
+    free(searchaddr);
     if (ret < 0) {
         return DB_ERROR;
     } else if ((ret == NOT_ENC) || (ret == ENC)) {
@@ -1306,3 +1329,39 @@ make_part_filter(char **filter, char *str, char *last, int *total_len)
   
     return SUCCESS;
 }
+
+/*
+ * str_tolower()
+ * translate lower string
+ *
+ * Args:
+ * char *rcptaddr           Recipient address
+ *
+ * Returns:
+ * lower_addr               translated rcptaddr
+ * NULL                     malloc error
+ */
+char *
+str_tolower(char *rcptaddr)
+{
+    char *lower_addr = NULL;
+    int len;
+    int i;
+
+    len = strlen(rcptaddr);
+
+    /* allocate enough size buffer */
+    lower_addr = (char *)malloc(len + 1);
+    if (lower_addr == NULL) {
+       /* malloc error */
+       return NULL;
+    }
+
+    /* translate lower string */
+    for (i = 0; i < len; i++) {
+        lower_addr[i] = tolower(rcptaddr[i]);
+    }
+    lower_addr[i] = '\0';
+
+    return lower_addr;
+}
