@@ -20,9 +20,12 @@
 
 /*
  * $RCSfile: sendmail.c,v $
- * $Revision: 1.7 $
- * $Date: 2010/03/23 03:35:34 $
+ * $Revision: 1.8 $
+ * $Date: 2010/07/15 06:27:30 $
  */
+#ifdef HAVE_STRNDUP
+#define _GNU_SOURCE
+#endif /* HAVE_STRNDUP */
 
 #include <stdio.h>
 #include <stdlib.h>
